Index: src/x87/macro-assembler-x87.h |
diff --git a/src/x87/macro-assembler-x87.h b/src/x87/macro-assembler-x87.h |
index 16a323f528b232dcc5343cdf52f3a139acff7df8..b7972651d51eb56645c4aced6bb0ea291ba089c1 100644 |
--- a/src/x87/macro-assembler-x87.h |
+++ b/src/x87/macro-assembler-x87.h |
@@ -378,14 +378,12 @@ class MacroAssembler: public Assembler { |
Label* fail, |
SmiCheckType smi_check_type); |
- // Check if the map of an object is equal to a specified map and branch to a |
- // specified target if equal. Skip the smi check if not required (object is |
- // known to be a heap object) |
- void DispatchMap(Register obj, |
- Register unused, |
- Handle<Map> map, |
- Handle<Code> success, |
- SmiCheckType smi_check_type); |
+ // Check if the map of an object is equal to a specified weak map and branch |
+ // to a specified target if equal. Skip the smi check if not required |
+ // (object is known to be a heap object) |
+ void DispatchWeakMap(Register obj, Register scratch1, Register scratch2, |
+ Handle<WeakCell> cell, Handle<Code> success, |
+ SmiCheckType smi_check_type); |
// Check if the object in register heap_object is a string. Afterwards the |
// register map contains the object map and the register instance_type |